# Luxsci::UsersApi

All URIs are relative to *https://rest.luxsci.com/perl/api/v2*, unless a hostname is provided ([see README](../README.md#documentation-for-api-endpoints))

Method | HTTP request | Description
------------- | ------------- | -------------
[**change_user_password**](UsersApi.md#change_user_password) | **PUT** /user/{username}/password | 
[**create_app_specific_password**](UsersApi.md#create_app_specific_password) | **POST** /user/{username}/app-password/{suffix} | 
[**create_user**](UsersApi.md#create_user) | **POST** /account/{accountId}/users | 
[**delete_app_specific_password**](UsersApi.md#delete_app_specific_password) | **DELETE** /user/{username}/app-password/{suffix} | 
[**delete_user**](UsersApi.md#delete_user) | **DELETE** /account/{accountId}/users/{username} | 
[**get_time_zones_list**](UsersApi.md#get_time_zones_list) | **GET** /user/{username}/settings/timezones | 
[**get_user**](UsersApi.md#get_user) | **GET** /user/{username} | 
[**get_user_branding_information**](UsersApi.md#get_user_branding_information) | **GET** /user/{username}/branding | 
[**get_user_profile**](UsersApi.md#get_user_profile) | **GET** /user/{username}/profile | 
[**get_user_report**](UsersApi.md#get_user_report) | **GET** /account/{accountId}/users | 
[**get_user_report2**](UsersApi.md#get_user_report2) | **GET** /account/{accountId}/users/report | 
[**get_user_settings**](UsersApi.md#get_user_settings) | **GET** /user/{username}/settings | 
[**get_user_single_sign_on_login_url**](UsersApi.md#get_user_single_sign_on_login_url) | **GET** /user/{username}/password | 
[**get_user_summary_report**](UsersApi.md#get_user_summary_report) | **GET** /account/{accountId}/users/report_count | 
[**list_all_app_specific_password**](UsersApi.md#list_all_app_specific_password) | **GET** /user/{username}/app-password | 
[**list_app_specific_passwords**](UsersApi.md#list_app_specific_passwords) | **GET** /user/{username}/app-password/{suffix} | 
[**rename_user**](UsersApi.md#rename_user) | **POST** /account/{accountId}/users/{username}/rename | 
[**update_user**](UsersApi.md#update_user) | **PUT** /user/{username} | 
[**update_user_profile**](UsersApi.md#update_user_profile) | **PUT** /user/{username}/profile | 
[**update_user_settings**](UsersApi.md#update_user_settings) | **PUT** /account/{accountId}/users/{username} | 

# **change_user_password**
> InlineResponse201 change_user_password(username, opts)



This command changes the user’s password. It validates the new password using all the same tests that would be applied if you were changing the password in the Web Interface. Make sure that the configuration settings for password strength validation are compatible with that used by your own applications generating the passwords.  You cannot change the passwords of users that have been disabled. You must re-enable them first, then change the password. {{ACL: User Settings - Change Password}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::UsersApi.new
username = 'username_example' # String | 
opts = { 
  body: Luxsci::UsernamePasswordBody.new # UsernamePasswordBody | 
}

begin
  result = api_instance.change_user_password(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UsersApi->change_user_password: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **body** | [**UsernamePasswordBody**](UsernamePasswordBody.md)|  | [optional] 

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



# **create_app_specific_password**
> InlineResponse2011 create_app_specific_password(usernamesuffix, opts)



This command creates a new user app-specific password/login for a specific user. Note that users can have at most 30 app-specific passwords defined at any one time. {{ACL: User Settings - Change Password}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::UsersApi.new
username = 'username_example' # String | 
suffix = 'suffix_example' # String | It is the plain text suffix to the user’s regular login email address that will be used to create this new app-specific password. E.g., if you specify “email” as the suffix for the user ‘user@domain.com’, then the new login will be ‘usr@domain.com/email’.  The suffix string must be 1-10 characters long and can only contain letters and numbers. It is also case insensitive (so will be converted to lower case).'
opts = { 
  body: Luxsci::ApppasswordSuffixBody.new # ApppasswordSuffixBody | 
}

begin
  result = api_instance.create_app_specific_password(usernamesuffix, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UsersApi->create_app_specific_password: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **suffix** | **String**| It is the plain text suffix to the user’s regular login email address that will be used to create this new app-specific password. E.g., if you specify “email” as the suffix for the user ‘user@domain.com’, then the new login will be ‘usr@domain.com/email’.  The suffix string must be 1-10 characters long and can only contain letters and numbers. It is also case insensitive (so will be converted to lower case).&#x27; | 
 **body** | [**ApppasswordSuffixBody**](ApppasswordSuffixBody.md)|  | [optional] 

### Return type

[**InlineResponse2011**](InlineResponse2011.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



# **create_user**
> InlineResponse20057 create_user(account_id, opts)



Create a new user in your account.  Your API Interface looks to see how many users were added to your account in the past 24 hours. If this number is equal or greater than your API create limit, then your API will reject additional user creation requests until that situation changes. See your API Interface configuration page for your user creation limit.  If you would like to update other user information, such as contact information, disk quota, etc., you would use other, specific API calls. The user’s initial preferences are copied from the account main administrator user. This user will have all licenses and services that are currently being purchased “for all users” in your account or which are required (e.g. SecureLine for HIPAA or Archival in a domain provisioned for Archival).  **Upgrades:** If your account does not have available user licenses (or licenses for SecureLine, Archival, or other needed services) for this new user, then either the request will be rejected, or your account will be auto-upgraded if you have “Permit auto-upgrades as needed for fulfill requests” enabled. In the latter case, your account will be upgraded by a block of at least your specified “licenses at a time” upgrade setting from your API Interface configuration. {{ACL: Account: Users - Add}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::UsersApi.new
account_id = 'account_id_example' # String | 
opts = { 
  body: Luxsci::AccountIdUsersBody.new # AccountIdUsersBody | 
}

begin
  result = api_instance.create_user(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UsersApi->create_user: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_id** | **String**|  | 
 **body** | [**AccountIdUsersBody**](AccountIdUsersBody.md)|  | [optional] 

### Return type

[**InlineResponse20057**](InlineResponse20057.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



# **delete_app_specific_password**
> InlineResponse201 delete_app_specific_password(username, suffix, opts)



This command removes a user app-specific password/login for a specific user. {{ACL: User Settings - Change Password}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::UsersApi.new
username = 'username_example' # String | 
suffix = 'suffix_example' # String | It is the plain text suffix to the user’s regular login email address that will be used to identify the app-specific password. E.g., if you specify “email” as the suffix for the user ‘user@ domain.com’, then the login deleted will be ‘usr@domain.com/email’.
opts = { 
}

begin
  result = api_instance.delete_app_specific_password(username, suffix, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UsersApi->delete_app_specific_password: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **suffix** | **String**| It is the plain text suffix to the user’s regular login email address that will be used to identify the app-specific password. E.g., if you specify “email” as the suffix for the user ‘user@ domain.com’, then the login deleted will be ‘usr@domain.com/email’. | 

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **delete_user**
> InlineResponse2003 delete_user(account_id, username, opts)



Delete the user from the system. This eliminates all the user’s data, history, web/ftp files, and email. After this command is complete, there will no longer be any record that the user existed. **This command cannot be undone.**  Note that some users cannot be deleted in this way. For example, any user with “account management” permission cannot be deleted. Other users may not be able to be deleted if there are things in your account (e.g., web sites) that are still owned by them. You will receive an error if you try to delete a user that is not currently deletable.  Note that deletion of a user does not downgrade your account. Please contact billing for account downgrade requests. {{ACL: Account: Users - Enable/Disable/Delete}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::UsersApi.new
account_id = 'account_id_example' # String | 
username = 'username_example' # String | 
opts = { 
}

begin
  result = api_instance.delete_user(account_id, username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UsersApi->delete_user: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_id** | **String**|  | 
 **username** | **String**|  | 

### Return type

[**InlineResponse2003**](InlineResponse2003.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **get_time_zones_list**
> InlineResponse2003 get_time_zones_list(username, opts)



Return a list of all available time zones. The keywords are the canonical time zone names. The values are plain text versions of the names.  Note, that with the “GMT+/-” times, specifically, the canonical name has the opposite sign compared to the common plain text version we all are used to seeing. E.g. “GMT-5” for Eastern Time USA, has a canonical name of “GMT+5”. Ya, weird, but based on how the standard time zone database works – we use these canonical names in conjunction with the standard time zone database to translate times from one time zone to another. So, if you are in “GMT+5”, your saved time zone name will be “GMT-5” so that, behind the scenes, the software can use this database to properly handle your time.  {{ACL: User Settings - Read}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::UsersApi.new
username = 'username_example' # String | 
opts = { 
}

begin
  result = api_instance.get_time_zones_list(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UsersApi->get_time_zones_list: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 

### Return type

[**InlineResponse2003**](InlineResponse2003.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **get_user**
> InlineResponse2002 get_user(username, opts)



Return contact information and other general metadata for the user. {{ACL: User Settings - Read}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::UsersApi.new
username = 'username_example' # String | 
opts = { 
}

begin
  result = api_instance.get_user(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UsersApi->get_user: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 

### Return type

[**InlineResponse2002**](InlineResponse2002.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **get_user_branding_information**
> InlineResponse2006 get_user_branding_information(username, opts)



Return information that can be used to brand (private label) a user interface consistently with the branding the user would experience when logging in to WebMail. Other keywords may be added in the future as the need arises. {{ACL: User Settings - Read}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::UsersApi.new
username = 'username_example' # String | 
opts = { 
}

begin
  result = api_instance.get_user_branding_information(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UsersApi->get_user_branding_information: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 

### Return type

[**InlineResponse2006**](InlineResponse2006.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **get_user_profile**
> InlineResponse2004 get_user_profile(username, opts)



Return contact information and other general metadata for the user.  This endpoint is the same as `getUser`. {{ACL: User Settings - Read}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::UsersApi.new
username = 'username_example' # String | 
opts = { 
}

begin
  result = api_instance.get_user_profile(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UsersApi->get_user_profile: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 

### Return type

[**InlineResponse2004**](InlineResponse2004.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **get_user_report**
> InlineResponse20056 get_user_report(account_id, opts)



Return an array of information about all users matching your query request.  The Request query string can contain any or all of the following keywords parameters to refine the search. If all are omitted, the report will include information about all users in the account. In all cases, any users protected from API access will not be included in the report. {{ACL: User Settings: Read Access }}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::UsersApi.new
account_id = 'account_id_example' # String | 
opts = { 
  status: 'status_example', # String | Value ‘enabled’ – return only active/enabled users.<br>Value ‘disabled’ – return only disabled users.
  domain: 'domain_example', # String | Domain name in your account. If supplied, only users in this domain will be returned.
  younger_than: 56, # Integer | Return only users created less than this number of days ago.
  older_than: 56, # Integer | Return only users created more than this number of days ago.
}

begin
  result = api_instance.get_user_report(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UsersApi->get_user_report: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_id** | **String**|  | 
 **status** | **String**| Value ‘enabled’ – return only active/enabled users.&lt;br&gt;Value ‘disabled’ – return only disabled users. | [optional] 
 **domain** | **String**| Domain name in your account. If supplied, only users in this domain will be returned. | [optional] 
 **younger_than** | **Integer**| Return only users created less than this number of days ago. | [optional] 
 **older_than** | **Integer**| Return only users created more than this number of days ago. | [optional] 

### Return type

[**InlineResponse20056**](InlineResponse20056.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **get_user_report2**
> InlineResponse20021 get_user_report2(account_id, opts)



This report-style API call returns a list of all users in the account, with optional date range selection by user creation date. See also [API Reporting Basics](/rest-api/reporting.html) and [report header columns in the response](/rest-api/report-responses.html#users). {{ACL: Account: View Reports}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::UsersApi.new
account_id = 'account_id_example' # String | 
opts = { 
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example', # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  status: 'status_example', # String | Specify one of enabled or disabled to retrieve only enabled or disabled users.
  domain: 'domain_example', # String | Enter the name of a domain to retrieve only users whose login is in that domain.
}

begin
  result = api_instance.get_user_report2(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UsersApi->get_user_report2: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_id** | **String**|  | 
 **after_date** | **String**| DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT | [optional] 
 **before_date** | **String**| DATETIME. Return only matches dated before this date time. | [optional] 
 **first_row** | **Integer**| (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row&#x3D;50000 to get rows 50000 to 99,999. | [optional] [default to 0]
 **from_date** | **String**| DATETIME. Return only matches dated on or after this date time. | [optional] 
 **matches** | **Integer**| (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets. | [optional] [default to 50000]
 **through_date** | **String**| DATETIME. Return only matches dated before or on this date time. | [optional] 
 **destination** | **String**| For reporting requests.  Specifying a destination makes the report \&quot;asynchronous.\&quot;  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \&quot;job number\&quot; and the filename that will be uploaded.  The supported value of \&quot;destination\&quot; is currently only \&quot;sftp\&quot; for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \&quot;destination\&quot; is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance. | [optional] 
 **destination_directory** | **String**| For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \&quot;chdir\&quot; command. | [optional] 
 **destination_hostname** | **String**| For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **destination_password** | **String**| For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **destination_username** | **String**| For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **status** | **String**| Specify one of enabled or disabled to retrieve only enabled or disabled users. | [optional] 
 **domain** | **String**| Enter the name of a domain to retrieve only users whose login is in that domain. | [optional] 

### Return type

[**InlineResponse20021**](InlineResponse20021.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **get_user_settings**
> InlineResponse2007 get_user_settings(username, opts)



Return information regarding selected user preferences and settings. Other keywords may be added in the future as the need arises. {{ACL: User Settings - Read}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::UsersApi.new
username = 'username_example' # String | 
opts = { 
}

begin
  result = api_instance.get_user_settings(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UsersApi->get_user_settings: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 

### Return type

[**InlineResponse2007**](InlineResponse2007.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **get_user_single_sign_on_login_url**
> InlineResponse2001 get_user_single_sign_on_login_url(username, ip, opts)



Create a URL that the user can click on which will automatically log the user into the Web Interface without needing to enter his/her username and password. For example, if the user has already authenticated himself in your system, you can use this API call to get a link that can be presented to the user so the user can then access WebMail or other services without needing to login again (e.g. “single sign-on”).  Notes: 1. This API call returns a URL. You can have the user click on that URL or you can redirect him/her to it. 2. This URL is valid for 15 minutes from the time of issuance. It can be used multiple times while it is in use. 3. These URLs are invalidated if the user’s password is changed. 4. These URLs will only work for someone coming from the IP address that your specified in your request for the URL 5. If a user has a preference that permits only OpenID/Social media logins to his/her account, then this auto-login URL will not work. 6. If a user has two-factor authentication enabled, then this URL will take him through the username/password portion of the login process; however, the user will still have to do the chosen second factor. 7. All logins via Single Sign-on are logged and are denoted as Single Sign-on logins in the user’s login history report.

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::UsersApi.new
username = 'username_example' # String | Optional. Path after the domain name to take the user to upon automatic sign in. If omitted, the default path of “/perl/member/email/messages.pl” will be used; this default takes one to view the WebMail INBOX folder. You can use this parameter to select other destinations.
ip = 'ip_example' # String | Required. This must be the IPv4 IP address that the end user is currently using. The resulting login URL will only work for someone who is coming from this specific IP address.
opts = { 
}

begin
  result = api_instance.get_user_single_sign_on_login_url(username, ip, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UsersApi->get_user_single_sign_on_login_url: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**| Optional. Path after the domain name to take the user to upon automatic sign in. If omitted, the default path of “/perl/member/email/messages.pl” will be used; this default takes one to view the WebMail INBOX folder. You can use this parameter to select other destinations. | 
 **ip** | **String**| Required. This must be the IPv4 IP address that the end user is currently using. The resulting login URL will only work for someone who is coming from this specific IP address. | 

### Return type

[**InlineResponse2001**](InlineResponse2001.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **get_user_summary_report**
> InlineResponse20021 get_user_summary_report(account_id, opts)



This report the number of users in the account, with optional date range selection by user creation date. See also [API Reporting Basics](/rest-api/reporting.html) and [report header columns in the response](/rest-api/report-responses.html#users_count).  {{ACL: Account: View Reports}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::UsersApi.new
account_id = 'account_id_example' # String | 
opts = { 
  after_date: 'after_date_example', # String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  before_date: 'before_date_example', # String | DATETIME. Return only matches dated before this date time.
  first_row: 0, # Integer | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  from_date: 'from_date_example', # String | DATETIME. Return only matches dated on or after this date time.
  matches: 50000, # Integer | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  through_date: 'through_date_example', # String | DATETIME. Return only matches dated before or on this date time.
  destination: 'destination_example', # String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  destination_directory: 'destination_directory_example', # String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  destination_hostname: 'destination_hostname_example', # String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  destination_password: 'destination_password_example', # String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  destination_username: 'destination_username_example', # String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  status: 'status_example', # String | Specify one of enabled or disabled to retrieve only enabled or disabled users.
  domain: 'domain_example', # String | Enter the name of a domain to retrieve only users whose login is in that domain.
}

begin
  result = api_instance.get_user_summary_report(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UsersApi->get_user_summary_report: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_id** | **String**|  | 
 **after_date** | **String**| DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT | [optional] 
 **before_date** | **String**| DATETIME. Return only matches dated before this date time. | [optional] 
 **first_row** | **Integer**| (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row&#x3D;50000 to get rows 50000 to 99,999. | [optional] [default to 0]
 **from_date** | **String**| DATETIME. Return only matches dated on or after this date time. | [optional] 
 **matches** | **Integer**| (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets. | [optional] [default to 50000]
 **through_date** | **String**| DATETIME. Return only matches dated before or on this date time. | [optional] 
 **destination** | **String**| For reporting requests.  Specifying a destination makes the report \&quot;asynchronous.\&quot;  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \&quot;job number\&quot; and the filename that will be uploaded.  The supported value of \&quot;destination\&quot; is currently only \&quot;sftp\&quot; for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \&quot;destination\&quot; is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance. | [optional] 
 **destination_directory** | **String**| For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \&quot;chdir\&quot; command. | [optional] 
 **destination_hostname** | **String**| For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **destination_password** | **String**| For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **destination_username** | **String**| For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **status** | **String**| Specify one of enabled or disabled to retrieve only enabled or disabled users. | [optional] 
 **domain** | **String**| Enter the name of a domain to retrieve only users whose login is in that domain. | [optional] 

### Return type

[**InlineResponse20021**](InlineResponse20021.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **list_all_app_specific_password**
> InlineResponse2005 list_all_app_specific_password(username, opts)



This command creates a list of all app-specific password/logins defined for a specific user. This command does not allow you to access the passwords themselves, as these are stored only as complex hashes on the server.  A list of all defined app-specific passwords will be returned.  {{ACL: User Settings - Change Password}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::UsersApi.new
username = 'username_example' # String | 
opts = { 
}

begin
  result = api_instance.list_all_app_specific_password(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UsersApi->list_all_app_specific_password: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 

### Return type

[**InlineResponse2005**](InlineResponse2005.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **list_app_specific_passwords**
> InlineResponse2005 list_app_specific_passwords(username, suffix, opts)



This command creates a list of all app-specific password/logins defined for a specific user. This command does not allow you to access the passwords themselves, as these are stored only as complex hashes on the server.   The list will contain either 0 results (if there is no app-specific password defined with that suffix), or the 1 singular result corresponding to that suffix. {{ACL: User Settings - Change Password}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::UsersApi.new
username = 'username_example' # String | 
suffix = 'suffix_example' # String | 
opts = { 
}

begin
  result = api_instance.list_app_specific_passwords(username, suffix, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UsersApi->list_app_specific_passwords: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **suffix** | **String**|  | 

### Return type

[**InlineResponse2005**](InlineResponse2005.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **rename_user**
> InlineResponse201 rename_user(account_idusername, opts)



Change the user’s login email address from `username` to `new_address`. E.g., change `john@sample.com` to `fred@newdomain.com`. Please note the following restrictions on this command:    1.  Users cannot be renamed with the API in the following situations:   1.  Users with account administration permission cannot be renamed.   2.  If this user is currently HIPAA compliant, s/he cannot be renamed into a domain that is not HIPAA compliant   3.  If this user does not have a SecureLine license, s/he cannot be renamed into a domain that is HIPAA- ompliant   4.  Users with Secure Marketing user logins associated with them cannot be renamed.   5.  Users cannot be renamed from a domain that does not have Premium Email Filtering or Archival into a domain that does. 2.  The new domain name (e.g. `newdomain.com`) must exist in this account. 3.  The user part of the new login (e.g. `fred`) must be valid for an email address and must not correspond to an existing user or email alias. 4.  Any existing PGP or S/MIME certificates associated with this user in the system will be deleted and become inaccessible, as they are explicitly related to the user’s login email address.  {{ACL: Account: Users - Enable / Disable / Delete Users}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::UsersApi.new
account_id = 'account_id_example' # String | 
username = 'username_example' # String | 
opts = { 
  body: Luxsci::UsernameRenameBody.new # UsernameRenameBody | 
}

begin
  result = api_instance.rename_user(account_idusername, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UsersApi->rename_user: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_id** | **String**|  | 
 **username** | **String**|  | 
 **body** | [**UsernameRenameBody**](UsernameRenameBody.md)|  | [optional] 

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



# **update_user**
> InlineResponse2003 update_user(username, opts)



Update contact information for the user.  Same as `updateUserProfile`.  {{ACL: User Settings - Write}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::UsersApi.new
username = 'username_example' # String | 
opts = { 
  body: Luxsci::UserUsernameBody.new # UserUsernameBody | 
}

begin
  result = api_instance.update_user(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UsersApi->update_user: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **body** | [**UserUsernameBody**](UserUsernameBody.md)|  | [optional] 

### Return type

[**InlineResponse2003**](InlineResponse2003.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



# **update_user_profile**
> InlineResponse2003 update_user_profile(username, opts)



Update contact information for the user. {{ACL: User Settings - Write}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::UsersApi.new
username = 'username_example' # String | 
opts = { 
  body: Luxsci::UsernameProfileBody.new # UsernameProfileBody | 
}

begin
  result = api_instance.update_user_profile(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UsersApi->update_user_profile: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **body** | [**UsernameProfileBody**](UsernameProfileBody.md)|  | [optional] 

### Return type

[**InlineResponse2003**](InlineResponse2003.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



# **update_user_settings**
> InlineResponse201 update_user_settings(account_idusername, opts)



Change one or more properties of the user. {{ACL: Account: Users - Modify}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::UsersApi.new
account_id = 'account_id_example' # String | 
username = 'username_example' # String | 
opts = { 
  body: Luxsci::UsersUsernameBody.new # UsersUsernameBody | 
}

begin
  result = api_instance.update_user_settings(account_idusername, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling UsersApi->update_user_settings: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_id** | **String**|  | 
 **username** | **String**|  | 
 **body** | [**UsersUsernameBody**](UsersUsernameBody.md)|  | [optional] 

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



